==> ckmame-2.1.tar.xz: ckmame-2.1/src/check_util.cc <==
/*
  check_util.c -- utility functions needed only by ckmame itself
  Copyright (C) 1999-2015 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "check_util.h"

#include <algorithm>

#include "Archive.h"
#include "CkmameDB.h"
#include "DeleteList.h"
#include "Dir.h"
#include "globals.h"
#include "util.h"
#include "CkmameCache.h"


std::string findfile(filetype_t filetype, const std::string &name) {
    if (filetype == TYPE_FULL_PATH) {
	if (std::filesystem::exists(name)) {
	    return name;
	}
	else {
	    return "";
	}
    }

    auto fn = make_file_name(filetype, name);
    if (std::filesystem::exists(fn)) {
	return fn;
    }

    return "";
}


std::string make_file_name(filetype_t filetype, const std::string &name) {
    std::string result;

    result = configuration.rom_directory + "/" + name;
    if (filetype == TYPE_ROM && configuration.roms_zipped) {
	result += ".zip";
    }

    return result;
}

==> ckmame-3.0.tar.xz: ckmame-3.0/src/check_util.cc <==
/*
  check_util.cc -- utility functions needed only by ckmame itself
  Copyright (C) 1999-2015 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "check_util.h"

#include <algorithm>

#include "Archive.h"
#include "CkmameDB.h"
#include "DeleteList.h"
#include "Dir.h"
#include "globals.h"
#include "util.h"
#include "CkmameCache.h"


std::string findfile(filetype_t filetype, const std::string &name) {
    if (filetype == TYPE_FULL_PATH) {
	if (std::filesystem::exists(name)) {
	    return name;
	}
	else {
	    return "";
	}
    }

    auto fn = make_file_name(filetype, name);
    if (std::filesystem::exists(fn)) {
	return fn;
    }

    return "";
}


std::string make_file_name(filetype_t filetype, const std::string &name) {
    std::string result;

    result = configuration.rom_directory + "/" + name;
    if (filetype == TYPE_ROM && configuration.roms_zipped) {
	result += ".zip";
    }

    return result;
}
